==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/src/config/e2_option_bool.h <==
/* $Id: e2_option_bool.h 762 2005-05-13 04:00:38Z tpgww $
 * 
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef E2_OPTION_BOOL_H
#define E2_OPTION_BOOL_H

GtkWidget *e2_option_bool_add_menu_widget (GtkWidget *controller,
	GtkWidget *menu, E2_OptionSet *set, gpointer func, gpointer data);
GtkWidget *e2_option_bool_add_dialog_widget (GtkWidget *dialog, GtkWidget *box,
	GtkSizeGroup *size_group, E2_OptionSet *set);
GtkWidget *e2_option_bool_add_expander_widget (GtkWidget *controller,
	GtkWidget *box, gchar *text, E2_OptionSet *set, GtkWidget *child);
E2_OptionSet *e2_option_bool_register (gchar *name, gchar *group, gchar *desc,
	gchar *tip, gchar *depends, gboolean def, E2_OptionFlags flags);
gboolean e2_option_bool_get (gchar *option);
gboolean _e2_option_bool_get (E2_OptionSet *set);
gboolean e2_option_bool_toggle (gchar *option);
gboolean _e2_option_bool_toggle (E2_OptionSet *set);
gboolean e2_option_bool_set (gchar *option, gboolean state);
gboolean _e2_option_bool_set (E2_OptionSet *set, gboolean value);

#endif /* ifndef E2_OPTION_BOOL_H */

==> emelfm2-0.1.7.tar.gz: emelfm2-0.1.7/src/config/e2_option_bool.h <==
/* $Id: e2_option_bool.h 1576 2006-02-07 02:38:29Z tpgww $
 * 
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef E2_OPTION_BOOL_H
#define E2_OPTION_BOOL_H

GtkWidget *e2_option_bool_add_menu_widget (GtkWidget *controller,
	GtkWidget *menu, E2_OptionSet *set, gpointer func, gpointer data);
GtkWidget *e2_option_bool_add_dialog_widget (GtkWidget *dialog, GtkWidget *box,
	GtkSizeGroup *size_group, E2_OptionSet *set);
GtkWidget *e2_option_bool_add_expander_widget (GtkWidget *controller,
	GtkWidget *box, gchar *text, E2_OptionSet *set, GtkWidget *child);
E2_OptionSet *e2_option_bool_register (gchar *name, gchar *group, gchar *desc,
	gchar *tip, gchar *depends, gboolean def, E2_OptionFlags flags);
gboolean e2_option_bool_get (gchar *option);
gboolean e2_option_bool_get_direct (E2_OptionSet *set);
gboolean e2_option_bool_toggle (gchar *option);
gboolean e2_option_bool_toggle_direct (E2_OptionSet *set);
gboolean e2_option_bool_set (gchar *option, gboolean state);
gboolean e2_option_bool_set_direct (E2_OptionSet *set, gboolean value);

#endif /* ifndef E2_OPTION_BOOL_H */
